---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2013-08-09;98
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20130820&codiceRedaz=13G00140&dataVigenza=20251104
dataGU: 20130820
codiceRedaz: 13G00140
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 21 giugno 2013, n. 69, recante disposizioni urgenti per il rilancio dell'economia. (13G00140)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 21 giugno 2013, n. 69, recante disposizioni urgenti per il rilancio dell'economia, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. Restano validi gli atti e i provvedimenti adottati e sono fatti salvi gli effetti prodottisi e i rapporti giuridici sorti sulla base delle norme del decreto-legge 24 giugno 2013, n. 72, recante misure urgenti per i pagamenti dei debiti degli enti del Servizio sanitario nazionale, non convertite in legge.

3. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

